
<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://img.riminder.net/logo-hrflow.svg" width="120" />
  </a>
</p>
<h1 align="center">
  Smartrecruiters connectors
</h1>


<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://www.jaimelesstartups.fr/wp-content/uploads/2020/11/Logo_SR_ok-1.png"/>
  </a>
</p>

<br/>
  Smartrecruiters is an HR product including an ATS (Applicant Tracking System), CRM (Candidate Relationship Management),
helping organizations attract and hire better talent.

## Getting Started
The connection between HrFlow.ai and Smartrecruiters exists as part of a flow, 
a continuum of events that gets something done.

This interactive flow uses mainly three concepts:
- Authentication
- HrFlow.ai APIs
- Smartrecruiters APIs


## Authentication
Enabling connection between **HrFlow.ai** and **Smartrecruiters**, you’ll be able
immediately to go through your integration. 

You need both HrFlow.ai token and Smartrecruiter token

### HrFlow.ai token
You can find your HrFlow.ai API credentials by clicking on API > Keys  tab in your dashboard settings
section.

please follow this [link](https://developers.hrflow.ai/getting-started/authentication) for further information.

<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://gblobscdn.gitbook.com/assets%2F-M1L6Hspq8r9LXd5_gIC%2F-MTkZzWWfGI1PHGVKHv0%2F-MTkawmrka2F7JNwKUCw%2Fapi_key.png?alt=media&token=fe3f1974-68ac-412d-aaa4-2cfe683b91ad"/>
  </a>
</p>

### Smartrecruiters token
Token is available in your Smartrecruiter account, you navigate to Settings/Admin 
then you will find the API key in API/Integrations. 

for more information please follow this [link](https://dev.smartrecruiters.com/customer-api/authentication/api-key/) in API / Integrations

<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://saml-doc.okta.com/Provisioning_Docs/images/apps/smartrecruiters1.png" width="300"/>
  </a>
</p>

## HrFlow.ai APIs

HrFlow.ai has designed and developed its APIs to solve many complex HR problems
and to rapidly build a production-ready integrations with modern tools such as Smartrecruiters.

<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://hrflow.ai/new/img/developer/stack.svg"/>
  </a>
</p>

Using HrFlow.ai AI stack you can connect to Smartrecruiters and enrich your data
before send it to your destination.


## Smartrecruiters APIs
SmartRecruiters APIs allow you to connect to all recruiting services.

These APIs help customers to push or pull data from/into Smartrecruiters

<p align="center">
  <a href="https://hrflow.ai">
    <img alt="hrflow" src="https://i0.wp.com/rapidapi.com/blog/directory/wp-content/uploads/2019/10/https_dev.smartrecruiters.com_marketplace-api_overview_.png?fit=640%2C459&ssl=1"/>
  </a>
</p>


